// Note: "QtQuick 1.0" needs Qt 4.7.1 so we "import Qt 4.7" instead for Qt 4.7.0

import QtQuick 1.0
//import Qt 4.7

import QtMultimediaKit 1.1

import com.basyskom.qmlcomponents 1.0

Rectangle {
    width: 360
    height: 360
    id: timePicMain

    // QML does not know Enums, so this will help:
    property int pageModeCommandView: 1;
    property int pageModeImageView:   2;
    property int pageMode: pageModeCommandView;


    PictureLabeler {
        id: labeler
    }


    Camera {
        id: cameraObject
        anchors.centerIn: parent
        width: 100
        height: 100

        onImageCaptured: {
            console.log("Image captured!" )
        }

        onImageSaved: {
            console.log("Image saved!" )
            imageFilename.color = "blue"
            imageFilename.text = capturedImagePath

            // Aufruf der C++-Methode unserer Hilfsklasse:
            var stamp = labeler.addTimestamp(capturedImagePath)
            if( stamp == "" ) {
                console.log("Could not write image time stamp into " + capturedImagePath )
                timeStamp.color = "red"
                timeStamp.text  = "ERROR: Could not write timestamp into " + capturedImagePath
            }else{
                console.log("Image time stamp saved as " + stamp )
                timeStamp.color = "blue"
                timeStamp.text  = "time stamp: " + stamp

                pageMode = pageModeImageView;
            }
        }
    }


    Rectangle {
        // the Quit button at the bottom of the area
        id: quitButton
        width: 80; height: 80
        anchors.bottom: parent.bottom;
        anchors.left: parent.left; anchors.right: parent.right; anchors.margins: 10
        color: "red"

        Text { text: "Quit"; font.pixelSize: 32; anchors.centerIn: parent }

        MouseArea {
            anchors.fill: parent
            hoverEnabled: true
            acceptedButtons: Qt.LeftButton

            onClicked: {
                Qt.quit();
            }
        }
    }

    Rectangle {
         id: mainArea
         anchors.top: parent.top
         anchors.left: parent.left
         anchors.right: parent.right
         anchors.bottom: quitButton.top


         //  * * * * *   C O M M A N D   V I E W   * * * * *

        Rectangle {
             id: commandView
             anchors.top: parent.top
             anchors.left: parent.left
             anchors.right: parent.right

            Text {
                // the last saved image filename
                id: imageFilename
                anchors {
                    top: parent.top
                    horizontalCenter: parent.horizontalCenter
                    topMargin: 20
                }
                text: "NO IMAGE"
                color: "red"
            }

            Text {
                // the timestamp of the last saved image file
                id: timeStamp
                anchors {
                    top: imageFilename.bottom
                    horizontalCenter: parent.horizontalCenter
                    topMargin: 20
                }
                text: "NO DATE"
                color: "red"
            }

            Rectangle {
                // Snapshot button
                id: snapshotButton
                width: 80; height: 80
                anchors.top: timeStamp.bottom;
                anchors.left: parent.left; anchors.right: parent.right; anchors.margins: 10
                color: "blue"

                Text {
                    text: "C A P T U R E   N E X T   P H O T O"
                    font.pixelSize: 32
                    color: "yellow"
                    anchors.centerIn: parent
                }

                MouseArea {
                    anchors.fill: parent
                    hoverEnabled: true
                    acceptedButtons: Qt.LeftButton

                    onClicked: {
                        console.log("Capturing a photo with ISO " + cameraObject.iso )
                        cameraObject.captureImage()
                    }
                }
            }
        }


        //  * * * * *   I M A G E   V I E W   * * * * *

        Rectangle {
             id: imageView
             anchors.fill: parent

             Image {
                 width: parent.width
                 height: parent.height
                 smooth: true
                 source: cameraObject.capturedImagePath
             }

             MouseArea {
                 anchors.fill: parent
                 hoverEnabled: true
                 acceptedButtons: Qt.LeftButton

                 onClicked: {
                     pageMode = pageModeCommandView;
                 }
             }
        }
    }



//  * * * * *   S T A T E S   * * * * *

    states: [
        State {
                name: "StateCommandView";
                when: timePicMain.pageMode == pageModeCommandView;
                PropertyChanges { target: commandView; opacity:1 }
                PropertyChanges { target: imageView; opacity:0 }
            },
        State {
                name: "StateImageView"
                when: timePicMain.pageMode == pageModeImageView;
                PropertyChanges { target: commandView; opacity:0 }
                PropertyChanges { target: imageView; opacity:1 }
            }
    ]


// * * * * *   T R A N S I T I O N S   * * * * *

    transitions:  [
        Transition {
            from: "StateCommandView"
            to: "StateImageView"
            reversible: false
            SequentialAnimation {
                NumberAnimation {
                    duration: 100
                    properties: "detailsOpacity,height"
                }
                ParallelAnimation {
                    ColorAnimation {
                        duration: 100
                        properties: "topColor, bottomColor"
                    }
                    NumberAnimation {
                        duration: 150
                        properties: "x"
                    }
                }
            }
        },
        Transition {
            from: "StateImageView"
            to: "StateCommandView"
            reversible: false
            ParallelAnimation {
                NumberAnimation {
                    duration: 250
                    properties: "contentY,opacity"
                }
                SequentialAnimation {
                    NumberAnimation {
                        duration: 100
                        properties: "detailsOpacity,height"
                    }
                    ParallelAnimation {
                        ColorAnimation {
                            duration: 100
                            properties: "topColor, bottomColor"
                        }
                        NumberAnimation {
                            duration: 150
                            properties: "x"
                        }
                    }
                }
            }
        }
    ]

}
